/*******************************************************************************
 * Copyright (c) 2013, Perforce Software
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 * 
 * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ******************************************************************************/
package com.perforce.p4java.extension.exception;

/**
 * <ul>
 * There are 3 categories of Exceptions:
 * <li>ServerConnectionException: if the Perforce server is unreachable or is
 * not connected.</li>
 * <li>ServerErrorException: if the Perforce server encounters an error during
 * its processing of the request</li>
 * <li>ServerAccessException: if the Perforce server denies access to the caller
 * </li>
 * </ul>
 */
public class ServerException extends Exception {

    private static final long serialVersionUID = 3982677445683374728L;

    public ServerException() {
	super();
    }

    public ServerException(String message, Throwable cause) {
	super(message, cause);
    }

    public ServerException(String message) {
	super(message);
    }

    public ServerException(Throwable cause) {
	super(cause);
    }

    @Override
    public String getMessage() {
	if (getCause() != null)
	    return super.getMessage() + "\n" + getCause().getMessage();
	else
	    return super.getMessage();
    }

    @Override
    public String getLocalizedMessage() {
	if (getCause() != null)
	    return super.getLocalizedMessage() + "\n"
		    + getCause().getLocalizedMessage();
	else
	    return super.getLocalizedMessage();
    }
}
